@@ -34,7 +34,7 @@ class Command(BaseCommand):
             raise CommandError('Local model %s is not configured to be linked to ACE.' % options['local_model'])
         
         AxilentContentRecord.objects.create(local_content_type=content_type,
-                                            local_id=int(options['local_id']),
+                                            local_id=options['local_id'],
                                             axilent_content_type=local_model.ACE.content_type,
                                             axilent_content_key=options['content_key'])
         
